bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.broadcasting_multiplier
===========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaToGaussianWishart.broadcasting_multiplier